Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(554)

Unified Diff: sdk/lib/io/file.dart

Issue 12314153: dart:io | Rename File.name to File.path. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Remove stray line break. Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: sdk/lib/io/file.dart
diff --git a/sdk/lib/io/file.dart b/sdk/lib/io/file.dart
index ff956c8ff7aad650b306afeffccb672121cd51e8..f42555ebb34e0c015373e2e3c4fbc92a96be958e 100644
--- a/sdk/lib/io/file.dart
+++ b/sdk/lib/io/file.dart
@@ -30,7 +30,7 @@ abstract class File extends FileSystemEntity {
/**
* Create a File object.
*/
- factory File(String name) => new _File(name);
+ factory File(String path) => new _File(path);
/**
* Create a File object from a Path object.
@@ -143,13 +143,13 @@ abstract class File extends FileSystemEntity {
RandomAccessFile openSync([FileMode mode = FileMode.READ]);
/**
- * Get the canonical full path corresponding to the file name.
+ * Get the canonical full path corresponding to the file path.
* Returns a [:Future<String>:] that completes with the path.
*/
Future<String> fullPath();
/**
- * Synchronously get the canonical full path corresponding to the file name.
+ * Synchronously get the canonical full path corresponding to the file path.
*/
String fullPathSync();
@@ -274,9 +274,9 @@ abstract class File extends FileSystemEntity {
Encoding encoding: Encoding.UTF_8});
/**
* Get the name of the file.
*/
- String get name;
+ String get path;
}
@@ -444,9 +444,9 @@ abstract class RandomAccessFile {
String toString();
/**
* Gets the name of the file underlying this RandomAccessFile.
*/
- String get name;
+ String get path;
}

Powered by Google App Engine
@@ -274,9 +274,9 @@ abstract class File extends FileSystemEntity {
Encoding encoding: Encoding.UTF_8});
/**
- * Get the name of the file.
+ * Get the path of the file.
*/
@@ -444,9 +444,9 @@ abstract class RandomAccessFile {
String toString();
/**
- * Gets the name of the file underlying this RandomAccessFile.
+ * Gets the path of the file underlying this RandomAccessFile.
*/
This is Rietveld 408576698